@@ -1,6 +1,5 @@
 use {
-    clap::{crate_name, value_t, value_t_or_exit, App, Arg},
-    log::*,
+    clap::{value_t, value_t_or_exit, App, Arg},
     solana_clap_utils::{
         input_parsers::{pubkey_of, pubkeys_of, value_of},
         input_validators::{
@@ -340,8 +339,6 @@ fn main() {
     };
     let _logger_thread = redirect_stderr_to_file(logfile);
 
-    info!("{} {}", crate_name!(), solana_version::version!());
-    info!("Starting validator with: {:#?}", std::env::args_os());
     solana_core::validator::report_target_features();
 
     // TODO: Ideally test-validator should *only* allow private addresses.
